@@ -602,8 +602,8 @@ def create_class_dictionaries(df_original, mapping_dicts, column: str):
     conversion_dict = {}
     bv_dict = {}
     for element in list_dict:
-        conversion_dict[f'{element[column]}'] = element['Conversions']
-        bv_dict[f'{element[column]}'] = element['BV']
+        conversion_dict[element[column]] = element['Conversions']
+        bv_dict[element[column]] = element['BV']
 
     bv_col = column + "_bv"
     mapping_dicts[bv_col]=bv_dict
